..  Titling
    ##++::==~~--''``

The :py:mod:`homogeneous <turberfield.utils.homogeneous>` module
================================================================

.. autoclass:: turberfield.utils.homogeneous.Homogeneous
   :members:

.. automodule:: turberfield.utils.homogeneous
   :members:
   :member-order: bysource

